<?php  
header("Expires: Mon, 26 Jul 1997 05:00:00 GMT" );
header("Last-Modified: " . gmdate( "D, d M Y H:i:s" ) . "GMT" );
header("Cache-Control: no-cache, must-revalidate" );
header("Pragma: no-cache" );
header("Content-type: text/x-json");
include($_SERVER['DOCUMENT_ROOT'] .'/script/HeaderInc.php');
if('XMLHttpRequest' == $_SERVER['HTTP_X_REQUESTED_WITH']) {
  $ObjJqGridMod = new JqGridMod();
  $ObjJqGridMod->SetArrayIn($_GET);
  $VarWhere = ' AND sm.svtmove_is_deleted IS NULL';
  if (true === isset($_GET['svtmove_date_b']) || true === isset($_GET['svtmove_date_e'])){
    $VarWhere .= SiteLibs::ConvertTextDateToSql('sm.svtmove_date', $_GET['svtmove_date_b'], $_GET['svtmove_date_e']);
  }
  if (true === isset($_GET['svt_id']) && true === is_numeric($_GET['svt_id'])){
    $VarWhere .= ' AND s.svt_id = "'. $_GET['svt_id'] .'"';
  }
  if(true === isset($_GET['_search']) && 'true' == $_GET['_search']){
    if(true === isset($ObjJqGridMod->filters) && '' != $ObjJqGridMod->filters){
      $VarWhere .= ' AND '. $ObjJqGridMod->generateSearchStringFromFilter();
    }
    if(true === isset($ObjJqGridMod->searchField) && '' != $ObjJqGridMod->searchField){
      $VarWhere .= ' AND '. $ObjJqGridMod->generateSearchStringFromSearchField();
    }
  }
  $VarWhere = SiteLibs::StripAndOrFirst($VarWhere);
  $VarOrder = $ObjJqGridMod->GetOrder();
  $VarLimit = $ObjJqGridMod->GetLimit();
  $ObjSvtMoveMod = new SvtMoveMod($MS_SP);
  $count = $ObjSvtMoveMod->GetFromDb('SqlCount', 'GetOne', $VarWhere);
  $total_pages = $ObjJqGridMod->GetTotalPages($count);
  $page = $ObjJqGridMod->GetPage();
  $ArrSvtMove = $ObjSvtMoveMod->GetFromDb('SqlAll', 'GetAll', $VarWhere, $VarOrder, $VarLimit);
  //SiteLibs::GetVarDump($ArrSvt);
  $ArrFields = array();
  foreach ($ArrSvtMove AS $key => $row){
    $VarName = '';
    if(true === isset($row['svt_name']) && '' != $row['svt_name']){
      $VarName = '<a target="_blank" class="ui-state-default" href="/'. $MS_SP->Sp_PathTop .'/SvtInformation.php?svt_id='. $row['svt_id'] .'">'. $row['svt_name'] .'</a>';
    }
    $ArrFields[$key]['id'] = $row['svtmove_id'];
    $ArrFields[$key]['cell'][] = $VarName.'';
    $ArrFields[$key]['cell'][] = $row['svt_buxname'].'';
    $ArrFields[$key]['cell'][] = $row['svttype_name'].'';
    $ArrFields[$key]['cell'][] = $row['svt_invnum'].'';
    $ArrFields[$key]['cell'][] = $row['svt_serialnum'].'';
    $ArrFields[$key]['cell'][] = $row['structureorganization_title_from'].'';
    $ArrFields[$key]['cell'][] = $row['users_fio_from'].'';
    $ArrFields[$key]['cell'][] = $row['structureorganization_title_to'].'';
    $ArrFields[$key]['cell'][] = $row['users_fio_to'].'';
    $ArrFields[$key]['cell'][] = $row['svtmove_date'].'';
    $ArrFields[$key]['cell'][] = $row['svtmove_note'].'';
  }
  $json = array("page" => $page, "total" => $total_pages, "records" => $count,"rows" => $ArrFields);
  echo json_encode($json);
}
include($_SERVER['DOCUMENT_ROOT'] .'/script/FooterInc.php');
?>